@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # @Author  : ydf
 # @Time    : 2019/8/8 0008 12:04
+import os
 import rabbitpy
 
 from function_scheduling_distributed_framework.publishers.base_publisher import AbstractPublisher, deco_mq_conn_error
@@ -18,6 +19,8 @@ class RabbitmqPublisherUsingRabbitpy(AbstractPublisher):
         self.rabbit_client = RabbitMqFactory(is_use_rabbitpy=1).get_rabbit_cleint()
         self.channel = self.rabbit_client.creat_a_channel()
         self.queue = self.channel.queue_declare(queue=self._queue_name, durable=True)
+        self.logger.error('rabbitpy 快速发布 有问题会丢失大量任务，如果使用 rabbitmq 建议设置中间件为 BrokerEnum.RABBITMQ_AMQPSTORM')
+        os._exit(444) # noqa
 
     # @decorators.tomorrow_threads(10)
     @deco_mq_conn_error
